character property
Optional character override. When set, this character is displayed instead of the original text character (e.g. for scramble effects).
Implementation
final String? character;
Optional character override. When set, this character is displayed instead of the original text character (e.g. for scramble effects).
final String? character;