segments property
Optional inline segments for mixed content (static + animated).
When set, effects are ignored for this item in favor of per-segment effects. The segments' text content must exactly concatenate to text or be ignored.
Implementation
final List<TextSegment>? segments;