repeat method

void repeat({
  1. int? count,
  2. bool reverse = false,
})

Repeats the animation, optionally a specific count and reverse.

count — number of repetitions (null = infinite). When set, the animation stops after count completions. reverse — when true, each cycle plays forward then backward, doubling the effective duration per cycle.

Implementation

void repeat({int? count, bool reverse = false}) =>
    _controller?.repeat(count: count, reverse: reverse);