SlideDirection enum
Direction from which characters slide into position.
Values
- left → const SlideDirection
-
Slides in from the left edge.
- right → const SlideDirection
-
Slides in from the right edge.
- up → const SlideDirection
-
Slides in from the top edge.
- down → const SlideDirection
-
Slides in from the bottom edge.
- topLeft → const SlideDirection
-
Slides in from the top-left corner.
- topRight → const SlideDirection
-
Slides in from the top-right corner.
- bottomLeft → const SlideDirection
-
Slides in from the bottom-left corner.
- bottomRight → const SlideDirection
-
Slides in from the bottom-right corner.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SlideDirection> - A constant List of the values in this enum, in order of their declaration.