fromCenter property
When true, characters spread outward symmetrically from the text center. When false, characters spread rightward from the first character.
Implementation
final bool fromCenter;
When true, characters spread outward symmetrically from the text center. When false, characters spread rightward from the first character.
final bool fromCenter;